summaryrefslogtreecommitdiff
path: root/buildscripts/utils.py
diff options
context:
space:
mode:
authorJason Carey <jcarey@argv.me>2015-07-09 14:05:20 -0400
committerJason Carey <jcarey@argv.me>2015-07-14 16:15:54 -0400
commite749ffad9b4fe3110d97f366ebe39e7c9a4edd9d (patch)
tree927e727645da9bfc80095bb124860e31e58e9d77 /buildscripts/utils.py
parent1af5f44f9ba2b7cff8e0457798b7a25b64e9fe69 (diff)
downloadmongo-e749ffad9b4fe3110d97f366ebe39e7c9a4edd9d.tar.gz
SERVER-18531 Integrate SpiderMonkey
Provides SpiderMonkey 38.0.1esr as a JS engine for mongo and mongod.
Diffstat (limited to 'buildscripts/utils.py')
-rw-r--r--buildscripts/utils.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/buildscripts/utils.py b/buildscripts/utils.py
index 62a2b1d13eb..a05a4f6f9f9 100644
--- a/buildscripts/utils.py
+++ b/buildscripts/utils.py
@@ -24,10 +24,10 @@ def getAllSourceFiles( arr=None , prefix="." ):
for x in os.listdir( prefix ):
if x.startswith( "." ) or x.startswith( "pcre-" ) or x.startswith( "32bit" ) or x.startswith( "mongodb-" ) or x.startswith("debian") or x.startswith( "mongo-cxx-driver" ):
continue
# XXX: Avoid conflict between v8 and v8-3.25 source files in
# src/mongo/scripting
# Remove after v8-3.25 migration.
- if x.find("v8-3.25") != -1:
+ if x.find("v8-3.25") != -1 or x.find("mozjs") != -1:
continue
full = prefix + "/" + x
if os.path.isdir( full ) and not os.path.islink( full ):
@@ -24,10 +24,10 @@ def getAllSourceFiles( arr=None , prefix="." ):
if x.startswith( "." ) or x.startswith( "pcre-" ) or x.startswith( "32bit" ) or x.startswith( "mongodb-" ) or x.startswith("debian") or x.startswith( "mongo-cxx-driver" ):
continue
- # XXX: Avoid conflict between v8 and v8-3.25 source files in
+ # XXX: Avoid conflict between v8, v8-3.25 and mozjs source files in
# src/mongo/scripting
# Remove after v8-3.25 migration.